@@ -1,8 +1,7 @@
 __Sender__      = ""
 __APIKey__      = ""
-__APIVersion__  = "1.05"
-__APIURL__      = "https://www.tnz.co.nz/api/json"
-#__APIURL__      = "http://192.168.1.79/api/json"
+__APIVersion__  = "2.01"
+__APIURL__      = "https://www.tnz.co.nz/api/v"+__APIVersion__;
 __APIHeaders__  = {
     "Content-Type": "application/json",
     "encoding": "utf-8"
