@@ -1,5 +1,6 @@
 import requests
 import json
+import asyncio
 
 from tnzapi.get._common import Common
 from tnzapi.base import ResultRequestResult
@@ -9,7 +10,7 @@ class Result(Common):
     """ Constructor """
     def __init__(self, kwargs):
 
-        super().__init__(kwargs)
+        #super().__init__(kwargs)
 
         self.SetArgs(kwargs)
 
@@ -33,7 +34,7 @@ class Result(Common):
     def __PostMessage(self):
         
         try:
-            r = requests.post(self.APIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
+            r = requests.post(self.APIURL+"/get/result", data=json.dumps(self.APIData), headers=self.APIHeaders)
             r.raise_for_status()
         except requests.exceptions.HTTPError as e:
             return ResultRequestResult(response=r)
@@ -42,6 +43,11 @@ class Result(Common):
 
         return ResultRequestResult(response=r)
 
+    """ Private async function to POST message to TNZ REST API """
+    async def __PostMessageAsync(self):
+        
+        return self.__PostMessage()
+
     """ Function to send message """
     def Poll(self, **kwargs):
 
@@ -58,6 +64,22 @@ class Result(Common):
         
         return self.__PostMessage()
 
+    """ Async Function to send message """
+    async def PollAsync(self, **kwargs):
+
+        self.SetArgs(kwargs)
+
+        if not self.Sender :
+            return ResultRequestResult(error="Missing Sender")
+        
+        if not self.APIKey :
+            return ResultRequestResult(error="Missing APIKey")
+        
+        if not self.MessageID:
+            return ResultRequestResult(error="Missing MessageID")
+        
+        return await asyncio.create_task(self.__PostMessageAsync())
+
     def __repr__(self):
         return self.__pretty__(self.APIData)
 
