@@ -1,5 +1,6 @@
 import requests
 import json
+import asyncio
 
 from tnzapi.send._common import Common
 
@@ -30,10 +31,29 @@ class TTS(Common):
     """ Constructor """
     def __init__(self, kwargs):
 
-        super().__init__(kwargs)
+        #super().__init__(kwargs)
 
         self.SetArgs(kwargs)
 
+    """ Destructor """
+    def __del__(self):
+
+        self.CallerID    = ""
+        self.Options     = ""
+
+        self.BillingAccount = ""
+
+        self.NumberOfOperators   = 0
+        self.RetryAttempts       = 0
+        self.RetryPeriod         = 1
+
+        self.TTSVoiceType                = "Female2"
+        self.MessageToPeople             = ""
+        self.MessageToAnswerPhones       = ""
+        self.CallRouteMessageToPeople    = ""
+        self.CallRouteMessageToOperators = ""
+        self.CallRouteMessageOnWrongKey  = ""
+
     """ Set Args """
     def SetArgs(self, kwargs):
 
@@ -129,7 +149,7 @@ class TTS(Common):
     def __PostMessage(self):
 
         try:
-            r = requests.post(self.APIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
+            r = requests.post(self.APIURL+"/send/tts", data=json.dumps(self.APIData), headers=self.APIHeaders)
             r.raise_for_status()
         except requests.exceptions.HTTPError as e:
             return MessageResult(response=r)
@@ -138,6 +158,11 @@ class TTS(Common):
 
         return MessageResult(response=r)
 
+    """ Private async function to POST message to TNZ REST API """
+    async def __PostMessageAsync(self):
+
+        return self.__PostMessage()
+
     """ AddKeypad Function """
     def AddKeypad(self, **kwargs):
 
@@ -172,6 +197,28 @@ class TTS(Common):
 
         return self.__PostMessage()
 
+    """ Async Function to send message """
+    async def SendMessageAsync(self, **kwargs):
+
+        self.SetArgs(kwargs)
+
+        if not self.Sender :
+            return MessageResult(error="Empty Sender")
+        
+        if not self.APIKey :
+            return MessageResult(error="Empty APIKey")
+
+        if self.WebhookCallbackURL and not self.WebhookCallbackFormat :
+            return MessageResult(error="Missing WebhookCallbackFormat - JSON or XML")
+        
+        if not self.Recipients:
+            return MessageResult(error="Empty Recipient(s)")
+
+        if not self.MessageToPeople:
+            return MessageResult(error="Empty MessageToPeople")
+
+        return await asyncio.create_task(self.__PostMessageAsync())
+
     def __repr__(self):
         return self.__pretty__(self.APIData)
 
