@@ -1,5 +1,6 @@
 import requests
 import json
+import asyncio
 
 from tnzapi.set._common import Common
 from tnzapi.base import SetRequestResult
@@ -9,7 +10,7 @@ class Abort(Common):
     """ Constructor """
     def __init__(self, kwargs):
 
-        super().__init__(kwargs)
+        #super().__init__(kwargs)
 
         self.SetArgs(kwargs)
 
@@ -33,7 +34,7 @@ class Abort(Common):
     def __PostMessage(self):
 
         try:
-            r = requests.post(self.APIURL, data=json.dumps(self.APIData), headers=self.APIHeaders)
+            r = requests.post(self.APIURL+"/set/abort", data=json.dumps(self.APIData), headers=self.APIHeaders)
             r.raise_for_status()
         except requests.exceptions.HTTPError as e:
             return SetRequestResult(response=r)
@@ -42,6 +43,11 @@ class Abort(Common):
         
         return SetRequestResult(response=r)
 
+    """ Private async function to POST message to TNZ REST API """
+    async def __PostMessageAsync(self):
+
+        return self.__PostMessage()
+
     """ Function to send message """
     def SendRequest(self,**kwargs):
 
@@ -58,6 +64,22 @@ class Abort(Common):
         
         return self.__PostMessage()
 
+    """ Async Function to send message """
+    async def SendRequest(self,**kwargs):
+
+        self.SetArgs(kwargs)
+
+        if not self.Sender :
+            return SetRequestResult(error="Empty Sender")
+        
+        if not self.APIKey :
+            return SetRequestResult(error="Empty API Key")
+        
+        if not self.MessageID:
+            return SetRequestResult(error="Empty Message ID")
+        
+        return await asyncio.create_task(self.__PostMessageAsync())
+
     def __repr__(self):
         return self.__pretty__(self.APIData)
 
